@@ -17,7 +17,7 @@ import logging as log
 from typing import Generic, List, Optional, Set, Tuple, TypeVar
 
 import pymysql
-from hspylib.core.exception.exceptions import DatabaseConnectionError, DatabaseError
+from datasource.exception.exceptions import DatabaseConnectionError, DatabaseError
 from hspylib.core.metaclass.singleton import AbstractSingleton
 from hspylib.core.namespace import Namespace
 from hspylib.core.tools.text_tools import quote
