@@ -18,7 +18,7 @@ import sqlite3
 from sqlite3 import Error
 from typing import Generic, List, Optional, Set, Tuple, TypeVar
 
-from hspylib.core.exception.exceptions import DatabaseConnectionError, DatabaseError
+from datasource.exception.exceptions import DatabaseConnectionError, DatabaseError
 from hspylib.core.metaclass.singleton import AbstractSingleton
 from hspylib.core.namespace import Namespace
 from hspylib.core.tools.text_tools import quote
